package cn.teammodel;

import cn.teammodel.dao.EvaluationRepository;
import cn.teammodel.dao.StudentRepository;
import cn.teammodel.manager.DingAlertNotifier;
import cn.teammodel.model.entity.Appraise;
import cn.teammodel.model.entity.AppraiseTreeNode;
import cn.teammodel.service.EvaluationService;
import cn.teammodel.service.impl.EvaluationServiceImpl;
import com.azure.cosmos.models.PartitionKey;
import com.azure.spring.data.cosmos.core.CosmosTemplate;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;
import java.util.UUID;

@SpringBootTest
class TeamModelExtensionApplicationTests {
    @Resource
    CosmosTemplate cosmosTemplate;

    @Autowired
    private DingAlertNotifier notifier;

    @Autowired
    StudentRepository studentRepository;
    @Autowired
    private EvaluationRepository evaluationRepository;

    @Test
    void contextLoads() {
        notifier.send("告警: 测试消息推送封装模块");
    }

    @Test
    public void testCrud() {
        Appraise appraise = new Appraise();
        appraise.setCode("evaluation");
        appraise.setPeriodId("default");
        List<AppraiseTreeNode> nodes = new ArrayList<>();

        // 1
        String rootId = UUID.randomUUID().toString();
        AppraiseTreeNode node = new AppraiseTreeNode();
        node.setId(rootId);
        node.setPid(null);
        node.setName("root");
        node.setScore(0);
        // 2
        AppraiseTreeNode node1 = new AppraiseTreeNode();
        String subId = UUID.randomUUID().toString();
        node1.setId(subId);
        node1.setPid(rootId);
        node1.setName("child-1");
        node1.setScore(0);
        // 3
        AppraiseTreeNode node2 = new AppraiseTreeNode();
        node2.setId(UUID.randomUUID().toString());
        node2.setPid(subId);
        node2.setName("child-2");
        node2.setScore(0);
        nodes.add(node);
        nodes.add(node1);
        nodes.add(node2);
        appraise.setNodes(nodes);

        Appraise saved = cosmosTemplate.insert(appraise, null);
        System.out.println(saved);
    }

    @Test
    public void testSelect() {
        Appraise saved = evaluationRepository.findBySchoolId("hbcn", new PartitionKey("evaluation"));
        EvaluationService service = new EvaluationServiceImpl();
        //System.out.println(JSONUtil.parse(service.buildTree(saved.getNodes())).toStringPretty());
    }
    @Test
    public void testUpdate() {
        //EvaluationTree saved = evaluationTreeRepository.findBySchoolId("hbcn", new PartitionKey("evaluation"));
        Appraise saved = evaluationRepository.findBySchoolId("hbcn", new PartitionKey("evaluation"));
        EvaluationService service = new EvaluationServiceImpl();
        //System.out.println(JSONUtil.parse(service.buildTree(saved.getNodes())).toStringPretty());
        evaluationRepository.save(saved);
    }

}
